@@ -1,9 +1,13 @@
+"""
+Where the matplotlib interactivity is implemented
 
+"""
 
 import warnings
 
 
 import numpy as np
+import scipy.sparse as scpsparse
 import matplotlib.pyplot as plt
 
 
@@ -274,7 +278,17 @@ class DataStock2(DataStock1):
 
     @property
     def dinteractivity(self):
-        return self._dinteractivity
+        return self.dobj.get('interactivity', {})
+
+    # ------------------
+    # show basic commands
+    # ------------------
+
+    def show_commands(self, verb=None, returnas=None):
+        return _class2_interactivity.show_commands(
+            verb=verb,
+            returnas=returnas,
+        )
 
     # ------------------
     # Debug mode
@@ -576,16 +590,44 @@ class DataStock2(DataStock1):
             # requires re-initializing because home is a Qt Action
             # only created by toolbar.addAction()
             v0['handle'].manager.toolbar.home = self.new_home
-            try:
-                # if _init_toolbar() implemented (matplotlib > )
-                v0['handle'].manager.toolbar._init_toolbar()
-            except NotImplementedError:
+
+            # if _init_toolbar() implemented (matplotlib > )
+            error = False
+            if hasattr(v0['handle'].manager.toolbar, '_init_toolbar'):
+                try:
+                    v0['handle'].manager.toolbar._init_toolbar()
+                except NotImplementedError:
+                    v0['handle'].manager.toolbar.__init__(
+                        v0['handle'],
+                        v0['handle'].parent(),
+                    )
+                except Exception as err:
+                    error = err
+            elif hasattr(v0['handle'], 'parent'):
                 v0['handle'].manager.toolbar.__init__(
                     v0['handle'],
                     v0['handle'].parent(),
                 )
-            except Exception as err:
-                raise err
+            else:
+                error = True
+
+            if error is not False:
+                import platform
+                import sys
+                lstr0 = [f"\t- {k1}" for k1 in dir(v0['handle'])]
+                lstr1 = [f"\t- {k1}" for k1 in dir(v0['handle'].manager.toolbar)]
+                msg = (
+                    f"platform: {platform.platform()}\n"
+                    f"python: {sys.version}\n"
+                    f"backend: {plt.get_backend()}\n"
+                    "canvas attributes:\n"
+                    + "\n".join(lstr0)
+                    + "\ntoolbar attributes:\n"
+                    + "\n".join(lstr1)
+                )
+                if error is not True:
+                    msg += '\n' + str(err)
+                raise Exception(msg)
 
             self._dobj['canvas'][k0]['cid'] = {
                 'keyp': keyp,
@@ -841,13 +883,15 @@ class DataStock2(DataStock1):
         # --- Redraw all objects (due to background restore) --- 25 ms
         for k0, v0 in self._dobj['mobile'].items():
             v0['handle'].set_visible(v0['visible'])
-            try:
-                self._dobj['axes'][v0['axes']]['handle'].draw_artist(v0['handle'])
-            except Exception:
-                print(0, k0)        # DB
-                print(1, v0['axes'])    # DB
-                print(2, self._dobj['axes'][v0['axes']]['handle'])  # DB
-                print(3, v0['handle'])  # DB
+            # try:
+            self._dobj['axes'][v0['axes']]['handle'].draw_artist(v0['handle'])
+            # except Exception as err:
+                # print(0, k0)        # DB
+                # print(1, v0['axes'])    # DB
+                # print(2, self._dobj['axes'][v0['axes']]['handle'])  # DB
+                # print(3, v0['handle'])  # DB
+                # print(err)
+                # print()
 
         # ---- blit axes ------ 5 ms
         for aa in lax:
@@ -949,6 +993,11 @@ class DataStock2(DataStock1):
             cdy = self._ddata[cur_datay]['data']
             dx = np.diff(ax.get_xlim())
             dy = np.diff(ax.get_ylim())
+
+            if scpsparse.issparse(cdx) or scpsparse.issparse(cdy):
+                msg = "No handling of pts selection for sparse data yet!"
+                raise Exception(msg)
+
             dist = ((cdx - event.xdata)/dx)**2 + ((cdy - event.ydata)/dy)**2
             if dist.ndim == 1:
                 ix = np.nanargmin(dist)
